var expect = require('chai').expect,
	augmented = require('../src/augmented');

describe('augmented', function() {
	
	describe('#rewrite', function() {

		it('throws on invalid syntax', function() {
			function runInvalid() {
				return augmented.rewrite('some random bullshit');
			}

			expect(runInvalid).to.throw();
		});

		it('throws if a function has both await and yield', function() {
			function runInvalid() {
				return augmented.rewrite('(function() { yield 1; await 2; })()');
			}

			expect(runInvalid).to.throw('A function can\'t be both async and a generator.');
		});

		it('throws if a generator functions returns value', function() {
			function runInvalid() {
				return augmented.rewrite('(function() { yield 1; return 2; })()');
			}

			expect(runInvalid).to.throw('A generator function can\'t return values.');
		});

		it('does not throw if generator functions returns empty', function() {
			function runValid() {
				return augmented.rewrite('(function() { yield 1; return; })()');
			}

			expect(runValid).to.not.throw();
		});

	});

});